@@ -23,6 +23,8 @@ interface TextWithAttr {
     fg:AU_Color;
     bg:AU_Color;
     bold:boolean;
+    italic: boolean;
+    underline: boolean;
     text:string;
 }
 
@@ -50,7 +52,7 @@ interface TextPacket {
 
 class AnsiUp
 {
-    VERSION = "5.0.0";
+    VERSION = "5.1.0";
 
     //
     // *** SEE README ON GITHUB FOR PUBLIC API ***
@@ -64,7 +66,8 @@ class AnsiUp
     private fg:AU_Color;
     private bg:AU_Color;
     private bold:boolean;
-
+    private italic: boolean;
+    private underline:boolean;
     private _use_classes:boolean;
 
     private _csi_regex:RegExp;
@@ -83,6 +86,8 @@ class AnsiUp
         this._use_classes = false;
 
         this.bold = false;
+        this.italic = false;
+        this.underline = false;
         this.fg = this.bg = null;
 
         this._buffer = '';
@@ -467,7 +472,7 @@ class AnsiUp
                           |                           # alternate
                           (?:\x07)                    # BEL (what xterm did)
                         )
-                        ([\x21-\x7e]+)              # TEXT capture
+                        ([\x20-\x7e]+)              # TEXT capture
                         \x1b\]8;;                   # OSC Hyperlink End
                         (?:                         # ST
                           (?:\x1b\\)                  # ESC \
@@ -538,7 +543,7 @@ class AnsiUp
     }
 
     private with_state(pkt:TextPacket):TextWithAttr {
-        return { bold: this.bold, fg: this.fg, bg: this.bg, text: pkt.text };
+        return { bold: this.bold, italic: this.italic, underline: this.underline, fg: this.fg, bg: this.bg, text: pkt.text };
     }
 
     private process_ansi(pkt:TextPacket)
@@ -558,10 +563,20 @@ class AnsiUp
           if (isNaN(num) || num === 0) {
               this.fg = this.bg = null;
               this.bold = false;
+              this.italic = false;
+              this.underline = false;
           } else if (num === 1) {
               this.bold = true;
+          } else if (num === 3) {
+              this.italic = true;
+          } else if (num === 4) {
+              this.underline = true;
           } else if (num === 22) {
               this.bold = false;
+          } else if (num === 23) {
+              this.italic = false;
+          } else if (num === 24) {
+              this.underline = false;
           } else if (num === 39) {
               this.fg = null;
           } else if (num === 49) {
@@ -624,7 +639,7 @@ class AnsiUp
         txt = this.escape_txt_for_html(txt);
 
         // If colors not set, default style is used
-        if (!fragment.bold && fragment.fg === null && fragment.bg === null)
+        if (!fragment.bold && !fragment.italic && !fragment.underline && fragment.fg === null && fragment.bg === null)
             return txt;
 
         let styles:string[] = [];
@@ -635,7 +650,13 @@ class AnsiUp
 
         // Note on bold: https://stackoverflow.com/questions/6737005/what-are-some-advantages-to-using-span-style-font-weightbold-rather-than-b?rq=1
         if (fragment.bold)
-            styles.push('font-weight:bold')
+            styles.push('font-weight:bold');
+        
+        if (fragment.italic)
+            styles.push('font-style:italic');
+
+        if (fragment.underline)
+            styles.push('text-decoration:underline');
 
         if (!this._use_classes) {
             // USE INLINE STYLES
